import { JSXElement, createSignal, onMount } from "solid-js";

import { CommentsIcon } from "../../Util/Icons";
import { getCommentCount } from "../../Util/api";

export default function CommentsButton(props: { postId: string }): JSXElement {
  const [commentCount, setCommentCount] = createSignal(0);

  const handleComments = async (): Promise<void> => {
    try {
      const count = await getCommentCount(props.postId);
      setCommentCount(count);
    } catch (error) {
      console.error("Error reading comments:", error);
    }
  };

  // Fetch comment count when the component mounts
  onMount(handleComments);

  return (
    <div class="flex p-1">
      <CommentsIcon />
      <span class="text-1xl countdown px-1.5 pt-1.5 text-center">
        <p style={{ "--value": commentCount() }} />
      </span>
    </div>
  );
}
